--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

--[[---------------------------------------------
	Returns the K Constant depending on the the specified elo
	the greater the k constant is, the more the elo growth is

	@return number the k constant
--]]---------------------------------------------
function arena.get_k(elo)
	--// Bigger for newcomers
	if elo < 1000 then
		return 40
	elseif elo < 2000 then 
		return 30
	elseif elo < 3000 then
		return 20
	end

	return 10
end

--[[---------------------------------------------
	Simulates the p(D) function of the elo formula
	New elo = old elo + k * (match result - p(D))

	@return number the k constant
--]]---------------------------------------------
function arena.get_p(diff)
	return 1 / (1 + (10 ^ (-diff / 400)))
end

--[[---------------------------------------------
	Returns winner and looser points depending on their elos
	
	@param number winner_elo: winner's elo points
	@param number looser_elo: looser's elo points
	@return number, number winner and looser points
--]]---------------------------------------------
function arena.calc_elo(winner_elo, looser_elo)
	local winner_k = arena.get_k(winner_elo)
	local looser_k = arena.get_k(looser_elo)

	local winner_p = arena.get_p(winner_elo - looser_elo)
	local looser_p = arena.get_p(looser_elo - winner_elo)

	local winner_points = math.ceil(winner_k * (1 - winner_p))
	local looser_points = math.ceil(looser_k * (0 - looser_p))

	return winner_points, looser_points
end