--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

--// Players who wants to play
arena.queue = {}

--[[---------------------------------------------------------------------------
	Add the specified player to the waiting queue if possible
	
	@param number id: player ID
	@return number nil [OK] or -1 [ERROR]
--]]---------------------------------------------------------------------------
function arena.add_player_to_queue(id)
	--// Already in
	if arena.inArray(arena.queue, id) then
		return -1
	end

	arena.queue[#arena.queue + 1] = id
	arena.server_msg("You have joined to the waiting queue", id)
end

--[[---------------------------------------------------------------------------
	Removes the specified player from the waiting queue
	
	@param number id: player ID
--]]---------------------------------------------------------------------------
function arena.remove_player_from_queue(id)
	arena.queue_remove(arena.queue, id)
end

--[[---------------------------------------------------------------------------
	Places the specified player into the queue by checking him
		
	@param table queue: a queue
	@param number id: player ID
--]]---------------------------------------------------------------------------
function arena.add_valid_player_to_queue(queue, id)
	--// Not a player
	if not player(id, "exists") or arena.spectator[id] or 
		arena.disconnected[id] then
		return
	end

	queue[#queue + 1] = id
end

--[[---------------------------------------------------------------------------
	Places players into the arena according to their new ranks
--]]---------------------------------------------------------------------------
function arena.place_queue()
	local p_queue = {} --// Full queue (actual players + newcomers)

	--// Only one arena
	if arena.MAX_STAGE == 1 then
		arena.add_valid_player_to_queue(p_queue, arena.winners[1])
		arena.add_valid_player_to_queue(p_queue, arena.loosers[1])
	else
		--// First arena
		arena.add_valid_player_to_queue(p_queue, arena.winners[1])
		arena.add_valid_player_to_queue(p_queue, arena.winners[2])

		--// Middle arenas
		for i = 2, arena.MAX_STAGE - 1 do
			arena.add_valid_player_to_queue(p_queue, arena.loosers[i - 1])
			arena.add_valid_player_to_queue(p_queue, arena.winners[i + 1])
		end

		--// Last arena
		arena.add_valid_player_to_queue(p_queue, arena.loosers[arena.MAX_STAGE - 1])
		arena.add_valid_player_to_queue(p_queue, arena.loosers[arena.MAX_STAGE])
	end

	--// Add newcomers to the queue
	for i = 1, #arena.queue do
		arena.add_valid_player_to_queue(p_queue, arena.queue[i])
	end

	local stage = 1 --// stage counter
	local p_counter = 0 --// player counter

	arena.debug("-----> QUEUE <-----")

	--// Finally place players into the arena
	for i = 1, #p_queue do
		local id = p_queue[i] --// player ID

		p_counter = p_counter + 1 --// a new player

		if p_counter == 1 then --// First player in the arena
			arena.player_1[stage] = id
			arena.stage[id] = stage
			arena.debug("Arena <" .. stage .. "> P1 = " .. id)
		else --// Second player in the arena
			arena.player_2[stage] = id
			arena.stage[id] = stage
			arena.debug("Arena <" .. stage .. "> P2 = " .. id)
			stage = stage + 1
			p_counter = 0
		end
	end

	arena.queue = {} --// Free again for other people
end