--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

--[[---------------------------------------------
	Updates arenas at the end of a round

	@param number stage: stage level
--]]---------------------------------------------
function arena.process_result(stage)
	--// Already updated
	if arena.stats_updated[stage] then 
		return
	end

	--// AFK Players
	if arena.winners[stage] == -1 and 
		arena.player_1[stage] > 0 and arena.player_2[stage] > 0 then
		arena.winners[stage] = arena.player_1[stage]
		arena.loosers[stage] = arena.player_2[stage]
	end

	--// Alone players
	if arena.is_alone(stage) then
		local alone_id = arena.get_alone_id(stage)
		arena.winners[stage] = alone_id

		if arena.loosers[stage] > 0 then --// SUICIDE
			arena.loosers[stage] = 0
		end

		arena.remove_alone_player(stage, alone_id)
	end

	--// ELO Stuff
	if arena.winners[stage] > 0 and arena.loosers[stage] > 0 then
		arena.update_players_elo(stage)
	end

	arena.stats_updated[stage] = true
end

--[[---------------------------------------------
	Updates players stages

	@param number stage: stage level
--]]---------------------------------------------
function arena.update_players_stages(stage)
	--// Winner & Loosers data
	local winner = arena.winners[stage]
	local looser = arena.loosers[stage]
	local winner_stage = arena.stage[winner]
	local looser_stage = arena.stage[looser]

	if winner > 0 then --// There's a winner
		if winner_stage then --// (and he's still on the server)
			if winner_stage > 1 then  --// This player can still move up 
				arena.stage[winner] = arena.stage[winner] - 1
				arena.debug(player(winner, "name") .. " next stage <" 
					.. arena.stage[winner] .. ">")
			else
				if not arena.leaders[winner] then
					arena.leaders[winner] = 1
				else
					arena.leaders[winner] = arena.leaders[winner] + 1
				end

				arena.champion = winner
			end
		end
	end

	--// There's a looser
	if looser > 0 then
		--// This player can still move down (and he's still on the server)
		if (looser_stage and looser_stage < arena.MAX_STAGE) 
			and not arena.disconnected[looser] then 
			arena.stage[looser] = arena.stage[looser] + 1
			arena.debug(player(looser, "name") .. " next stage <" 
				.. arena.stage[looser] .. ">")
		end
	end
end

--[[---------------------------------------------
	Updates players elos at the end of a round

	@param number stage: a stage level
--]]---------------------------------------------
function arena.update_players_elo(stage)
	--// Winner & looser cached data
	local winner, looser = arena.winners[stage], arena.loosers[stage]
	local winner_elo, looser_elo = arena.elo[winner], arena.elo[looser]
	local winner_name, looser_name = player(winner, "name"), player(looser, "name")

	--// Elo change
	local winner_points, looser_points = arena.calc_elo(
		winner_elo, looser_elo)

	--// Check winner leave
	if player(winner, "exists") then
		arena.server_msg(arena.GREEN .. "You " .. arena.WHITE ..
		"(elo " .. arena.GREEN .. winner_elo .. arena.WHITE .. ", " .. 
		arena.GREEN .. "+" .. winner_points .. arena.WHITE .. ") beat " .. 
		arena.PURPLE .. looser_name .. arena.WHITE .. " (elo " .. arena.PURPLE .. 
		looser_elo .. arena.WHITE .. ", " .. arena.RED .. looser_points .. 
		arena.WHITE .. ")", winner)

		--// Elo update
		arena.elo[winner] = winner_elo + winner_points
	end

	--// Check looser leave
	if player(looser, "exists") then
		arena.server_msg(arena.GREEN .. "You " .. arena.WHITE ..
		" (elo " .. arena.GREEN .. looser_elo .. arena.WHITE .. ", " .. 
		arena.RED .. looser_points .. arena.WHITE .. ") lost " .. arena.PURPLE .. 
		winner_name .. arena.WHITE .. " (elo " .. arena.PURPLE .. 
		winner_elo .. arena.WHITE .. ", " .. arena.GREEN .. "+" .. 
		winner_points .. arena.WHITE .. ")", looser)

		--// Elo update
		arena.elo[looser] = looser_elo + looser_points

		--// Negative fix
		if arena.elo[looser] < 0 then
			arena.elo[looser] = 0
		end
	end
end --// arena.update_players_elo()

--[[---------------------------------------------
	The specified player gave up

	@param number id: player ID
--]]---------------------------------------------
function arena.forfeit_win(id)
	local stage = arena.stage[id] --// Current arena stage

	if arena.stats_updated[stage] then
		return
	end

	local winner_name = "None" --// Winner nickname
	local looser_name = "None" --// Looser nickname

	arena.debug("Forfeit win at <" .. stage .. ">")

	arena.winners[stage] = arena.get_opponent(id)
	arena.loosers[stage] = id

	if arena.winners[stage] > 0 then --// Valid player
		winner_name = player(arena.winners[stage], "name")
	end

	if arena.loosers[stage] > 0 then --// Valid player
		looser_name = player(arena.loosers[stage], "name")
	end
	
	arena.debug("Winner: " .. winner_name)
	arena.debug("Looser: " .. looser_name)
	arena.process_result(stage)
end

--[[---------------------------------------------
	Displays the arena winner
--]]---------------------------------------------
function arena.display_winner()
	local winner_id = 0
	local max_victories

	--// Search for the maximum victories
	for id, victories in pairs(arena.leaders) do
		if not max_victories or victories > max_victories then
			winner_id = id
			max_victories = victories
		end
	end

	local winner_name = "None"

	if winner_id > 0 and player(winner_id, "exists") then
		winner_name = player(winner_id, "name")
		arena.server_msg(winner_name .. " has won the game with (" .. 
			arena.GREEN .. max_victories .. arena.WHITE .. ") victories !")
	end
end