--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

arena.round = 0 --// Current server round
arena.round_finished = false --// Flag

--[[---------------------------------------------
	Returns whether the current round is finished
		- Case #1: Alone players

	@return bool whether the current round is finished
--]]---------------------------------------------
function arena.is_round_finish()
	--// Through each arena
	for stage = 1, arena.MAX_STAGE do
		--// Player IDs
		local p1 = arena.player_1[stage]
		local p2 = arena.player_2[stage]

		--// Is there 2 players and the winner isn't determined yet ?
		if p1 > 0 and p2 > 0 and arena.winners[stage] == 0 then
			return false
		end
	end

	return true
end

--[[---------------------------------------------
	Determines rounds types
--]]---------------------------------------------
function arena.determine_rounds_types()
	--// Through all arenas
	for stage = 1, arena.MAX_STAGE do
		--// Alone = alone user preferences
		if arena.is_alone(stage) then
			local id = arena.get_alone_id(stage) --// player ID
			local alone_pref = arena.preferences[id] or 0

			if alone_pref ~= 0 then
				arena.round_type[stage] = alone_pref
			else
				arena.round_type[stage] = math.random(1, 4)
			end
		elseif arena.is_full(stage) then
			--// Players ID
			local p1 = arena.player_1[stage] 
			local p2 = arena.player_2[stage]
			--// Preferences
			local p1_pref = arena.preferences[p1]
			local p2_pref = arena.preferences[p2]


			if p1_pref == p2_pref then --// Same preference = users round type
				if p1_pref ~= 0 then
					arena.round_type[stage] = p1_pref
				else
					arena.round_type[stage] = math.random(1, 4)
				end
			else --// Random one
				local round_types = {2} --// Rifles

				--// Both have pistols rounds enabled
				if arena.pistols_enabled[p1] == 1 and 
					arena.pistols_enabled[p2] == 1 then
					round_types[#round_types + 1] = 1
				end

				--// Both have awp rounds enabled
				if arena.awp_enabled[p1] == 1 and 
					arena.awp_enabled[p2] == 1 then
					round_types[#round_types + 1] = 3
				end

				--// Both have lasers rounds enabled
				if arena.laser_enabled[p1] == 1 and 
					arena.laser_enabled[p2] == 1 then
					round_types[#round_types + 1] = 4
				end

				--// Both have knife rounds enabled
				if arena.knife_enabled[p1] == 1 and 
					arena.knife_enabled[p2] == 1 then
					round_types[#round_types + 1] = 5
				end

				arena.round_type[stage] = round_types[math.random(1, 
					#round_types)]
			end
		else
			arena.round_type[stage] = 0
		end
	end
end


--[[---------------------------------------------
	Returns the round weapons of the specified player

	@param number id: player ID
	@return string weapon list
--]]---------------------------------------------
function arena.round_weapons(id)
	local stage = arena.stage[id]
	local round_type = arena.round_type[stage]

	if round_type == 1 then
		local fav_pistol = arena.fav_pistols[id]

		if fav_pistol == 0 then
			return math.random(1, 6)
		end

		return arena.fav_pistols[id]
	elseif round_type == 2 then
		local fav_rifle = arena.fav_rifles[id]
		local rifles = {30, 32, 38, 39}

		if fav_rifle == 0 then
			return rifles[math.random(1, 4)]
		end

		return arena.fav_rifles[id]
	elseif round_type == 3 then
		return "35"
	elseif round_type == 4 then
		return "45"
	elseif round_type == 5 then
		return "x"
	end
end

function arena.check_round_end()
	if arena.is_round_finish() then
		arena.debug("*** FORCED ENDROUND ***")
		parse('endround 1')
	end
end