--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

--[[---------------------------------------------
	Returns whether there's an empty/incomplete arena

	@return bool whether there's an empty/incomplete arena
--]]---------------------------------------------
function arena.has_free_slots()
	--// Current players in the arena + the waiting queue
	local total_players = arena.arrayCount(arena.stage) + 
		arena.arrayCount(arena.queue)

	return total_players < 2 * arena.MAX_STAGE
end

--[[---------------------------------------------
	Returns true if a player is alone in this arena

	@param table data: an arena
	@return bool if a player is alone in this arena
--]]---------------------------------------------
function arena.is_alone(stage)
	return arena.get_alone_id(stage) ~= nil
end

--[[---------------------------------------------
	Returns the number of the alone player

	@param number stage: an arena stage
	@return number the alone slot
--]]---------------------------------------------
function arena.get_alone_id(stage)
	local p1 = arena.player_1[stage]
	local p2 = arena.player_2[stage]

	if p1 ~= 0 and p2 == 0 then return p1 end
	if p2 ~= 0 and p1 == 0 then return p2 end
end

--[[---------------------------------------------
	Returns true if this arena is empty

	@param number stage: an arena stage
	@return bool true if this arena is empty
--]]---------------------------------------------
function arena.is_empty(stage)
	return arena.player_1[stage] == 0 and 
		arena.player_2[stage] == 0
end

--[[---------------------------------------------
	Returns true if this arena is full

	@param number stage: an arena stage
	@return bool true if this arena is full
--]]---------------------------------------------
function arena.is_full(stage)
	return arena.player_1[stage] > 0 and 
		arena.player_2[stage] > 0
end