--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

arena.lines = {} --// Memorized lines
arena.line = 0 --// Lines index

--[[---------------------------------------------
	Returns whether the specified path exists

	@param string path: a file path
	@return bool whether the specified path exists
--]]---------------------------------------------
function arena.file_exists(path)
	local f = io.open(path) --// The file

	if not f then --// File error 
		return false 
	end

	f:close()
	return true
end

--[[---------------------------------------------
	Loads the specified file into memory

	@param string path: a file path
--]]---------------------------------------------
function arena.load_file(path)
	local f = io.open(path) --// The file

	if not f then --// File error
		arena.error("Cant load <" .. path .. ">")
		return 
	end

	local lines = {} --// Memorized lines

	--// Stores each line
	for line in f:lines() do
		lines[#lines + 1] = line
	end

	--// Update
	arena.lines = lines
	arena.line = 0

	f:close()
end

--[[---------------------------------------------
	Returns a line from the memorized lines

	@return string a line from the memorized lines or nil on EOF
--]]---------------------------------------------
function arena.read_line()
	arena.line = arena.line + 1
	return arena.lines[arena.line]
end

--[[---------------------------------------------
	Writes the specified lines into a file

	@param string path: a file path
	@param table lines: the lines to be written
--]]---------------------------------------------
function arena.write_lines(path, lines)
	local f = io.open(path, "w+") --// The file

	if not f then --// File error
		arena.error("Can't write in this file <" .. path .. ">")
		return 
	end 

	--// Write each line
	for i = 1, #lines do
		--// Appends a line return only if it's not the last element
		f:write(lines[i] .. (i ~= #lines and "\n" or ""))
	end

	f:close()
end