--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

--[[---------------------------------------------
	Initialize player variables

	@param number id: player ID
--]]---------------------------------------------
function arena.join(id)
	arena.load_stats(id)
	arena.refresh_stats(id)

	arena.stage[id] = 0
	arena.fav_pistols[id] = 0
	arena.fav_rifles[id] = 0
	arena.pistols_enabled[id] = 1
	arena.awp_enabled[id] = 0
	arena.laser_enabled[id] = 1
	arena.knife_enabled[id] = 0
	arena.preferences[id] = 0
	arena.disconnected[id] = false
	arena.spectator[id] = true
	arena.sfx_enabled[id] = 1

	--// Random weapons
	if player(id, "bot") then
		local rifles = {0, 30, 32, 38, 39}

		arena.fav_pistols[id] = math.random(0, 6)
		arena.fav_rifles[id] = rifles[math.random(1, 5)]
		arena.pistols_enabled[id] = math.random(0, 1)
		arena.awp_enabled[id] = math.random(0, 1)
		arena.laser_enabled[id] = math.random(0, 1)
		arena.knife_enabled[id] = math.random(0, 1)
		arena.preferences[id] = math.random(1, 3)
	end

	arena.server_msg("Welcome " .. player(id, "name") .. " on " .. 
		game("sv_name") .. " !", id)
	arena.server_msg("Version: " .. arena.GREEN .. "v" .. 
		arena._VERSION, id)
end

--[[---------------------------------------------
	Save player variables

	@param number id: player ID
--]]---------------------------------------------
function arena.leave(id)
	arena.remove_player_from_queue(id)
	arena.disconnected[id] = true

	--// Remove this player from an arena
	--// Check incase the player didn't join correctly
	if arena.stage[id] and arena.stage[id] > 0 then
		arena.forfeit_win(id)
		arena.remove_player(id)
		arena.check_round_end()
	end

	arena.save_stats(id)

	arena.disconnected[id] = nil
	arena.spectator[id] = nil
	arena.stage[id] = nil
	arena.corrupted[id] = nil
	arena.fav_pistols[id] = nil
	arena.fav_rifles[id] = nil
	arena.pistols_enabled[id] = nil
	arena.awp_enabled[id] = nil
	arena.laser_enabled[id] = nil
	arena.knife_enabled[id] = nil
	arena.preferences[id] = nil
	arena.sfx_enabled[id] = nil
end

--[[---------------------------------------------
	Called when a player died

	@param number victim: player ID
	@param number killer: player ID
--]]---------------------------------------------
function arena.die(victim, killer)
	local stage = arena.stage[victim] --// Arena stage

	if stage == 0 then  --// Not in the arena
		return 
	end

	--// Already won
	if arena.winners[stage] ~= 0 then
		return
	end
	
	--// Updates victim stuff
	arena.deaths[victim] = arena.deaths[victim] + 1
	arena.loosers[stage] = victim

	if killer > 0 then --// The killer is a player
		--// Update killer stats
		arena.kills[killer] = arena.kills[killer] + 1
		arena.winners[stage] = killer
	else --// Map or suicide
		--// Update the winner
		arena.winners[stage] = arena.get_opponent(victim)
	end

	arena.process_result(stage)	
	arena.check_round_end()
end

--[[---------------------------------------------
	Called when a player try to change his team

	@param number id: player ID
	@param number team: team number
	@param number look: player skin
--]]---------------------------------------------
function arena.team(id, team, look)
	if team > 0 then --// Going CT or TT
		if arena.stage[id] == 0 then --// Not yet in the arena
			if not arena.has_free_slots() then --// The arena is full
				arena.server_msg("The arena is full !", id)
				return 1
			else --// The arena has free slots
				if arena.add_player_to_queue(id) == -1 then
					arena.server_msg("You are already in the queue !", id)
					return 1
				end
			end
		end

		arena.spectator[id] = false
	else --// Going to spec
		if arena.stage[id] > 0 then --// In the arena
			arena.spectator[id] = true
			arena.forfeit_win(id)
			arena.remove_player(id)
			arena.remove_player_from_queue(id)
			arena.check_round_end()
		end
	end
end

--[[---------------------------------------------
	Called when a player spawns

	@param number id: player ID
--]]---------------------------------------------
function arena.spawn(id)
	local stage = arena.stage[id]
	
	parse('setmoney ' .. id .. ' 0')

	if stage == 0 then --// Newcomers who didn't join the queue yet
		
		timer(100, "parse", 'killplayer ' .. tonumber(id))
		timer(100, "arena.dec_deaths", tonumber(id))

		arena.server_msg("You'll be placed in the arena, on the next round", id)
		return "x"
	end

	--// Champion image
	if arena.champion == id then
		arena.champion_img = image("gfx/xNir/arena/crown.png", 1, 0, 200 + id)
	end

	return arena.round_weapons(id)
end

--[[---------------------------------------------
	Called on player buy (disabled)

	@param number id: player ID
--]]---------------------------------------------
function arena.buy(id)
	return 1
end

--[[---------------------------------------------
	Called when a player sends a message

	@param number id: player ID
	@param string txt: a player message
--]]---------------------------------------------
function arena.say(id, txt)
	--// !BC Command
	if string.match(txt, "^!bc%s(.+)$") then
		local broadcast = string.match(txt, "^!bc%s(.+)$")
		msg(arena.ORANGE .. player(id, "name") .. " (BROADCAST): " .. arena.WHITE ..
			broadcast)
		return 1
	end
end