--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

arena.kills = {} --// Victories
arena.deaths = {} --// Defeats
arena.elo = {} --// Elo points
arena.corrupted = {} --// Flag for valid data
arena.disconnected = {} --// Flag for leavers
arena.spectator = {} --// Flag for spectators
arena.sfx_enabled = {} --// Flag for music

--[[---------------------------------------------
	Load player's stats

	@param number id: player ID
--]]---------------------------------------------
function arena.load_stats(id)
	if player(id, "bot") then --// Bots are newcomers
		arena.reset_player(id)
		return
	end

	local usgn = player(id, "usgn") --// player USGN
	local ip = player(id, "ip") --// player IP
	--// USGN based file path
	local usgn_path = arena._DATA_FOLDER .. usgn .. ".dat"
	--// IP base file path 
	local ip_path = arena._DATA_FOLDER .. ip .. ".dat"
	local user_path --// Valid file

	--// We suppose first that the file isn't corrupted
	arena.corrupted[id] = false 

	if usgn > 0 then --// The user has a valid USGN
		--// However the usgn file doesn't exists
		if not arena.file_exists(usgn_path) then
			--// The IP based eitheir, so he's probably a newcomer
			if not arena.file_exists(ip_path) then
				arena.reset_player(id)
			else --// IP based was found
				user_path = ip_path
			end
		else --// USGN based was found
			user_path = usgn_path
		end
	else --// USGN offline / no usgn
		--// Checking IP data
		if not arena.file_exists(ip_path) then
			arena.reset_player(id)
		else
			user_path = ip_path
		end
	end

	--// We don't need to go further for newcomers
	if not user_path then 
		return 
	end

	arena.load_file(user_path)

	local line = arena.read_line() --// Saved data

	--// The line must follow the data syntax
	if not line or not string.match(line, "^(%d+);(%d+);(%d+);$") then
		arena.debug("User corrupted <" .. user_path .. "> !")
		arena.reset_player(id)
		arena.corrupted[id] = true
		return
	end

	--// Loading user stats
	local kills, deaths, elo = string.match(line, "^(%d+);(%d+);(%d+);$")
	arena.kills[id] = tonumber(kills)
	arena.deaths[id] = tonumber(deaths)
	arena.elo[id] = tonumber(elo)

	arena.debug(player(id, "name") .. " loaded stats {" .. kills .. "," ..
		deaths .. ";" .. elo .. "}")
end

--[[---------------------------------------------
	Save player's stats

	@param number id: player ID
--]]---------------------------------------------
function arena.save_stats(id)
	--// The server won't save bot/corrupted data 
	--// Or not fully joined player
	if player(id, "bot") or not player(id, "exists") or arena.corrupted[id] or 
		not arena.kills[id] or not arena.deaths[id] or not arena.elo[id] then 
		return 
	end

	local usgn = player(id, "usgn") --// player USGN
	local ip = player(id, "ip") --// player IP
	local user_path --// Stats path depending on usgn
	local data = arena.kills[id] .. ";" ..  --// player stats
		arena.deaths[id] .. ";" .. arena.elo[id] .. ";" 

	if usgn > 0 then --// valid USGN
		user_path = arena._DATA_FOLDER .. usgn .. ".dat"
	else 
		user_path = arena._DATA_FOLDER .. ip .. ".dat"
	end

	arena.write_lines(user_path, {data})
	arena.debug(player(id, "name") .. " saved stats {" .. data .. "}")
end

--[[---------------------------------------------
	Refresh player's stats texts

	@param number id: player ID
--]]---------------------------------------------
function arena.refresh_stats(id)
	arena.hudtxt2(id, 0, "Elo: " .. arena.GREEN .. 
		arena.elo[id], 10, 150)
	arena.hudtxt2(id, 1, "Victories: " .. arena.GREEN .. 
		arena.kills[id], 10, 165)
	arena.hudtxt2(id, 2, "Defeats: " .. arena.RED .. 
		arena.deaths[id], 10, 180)
end