--[[---------------------------------------------------------------------------
	Multi 1v1 Arena mod
	By x[N]ir  USGN [#4841]
--]]---------------------------------------------------------------------------

arena.MAX_STAGE = 0 --// Total number of arenas
arena.maps = {} --// Arenas maps names
arena.maps_votes = {} --// Contains ids

--[[---------------------------------------------
	Check the map entities (Spawns)
--]]---------------------------------------------
function arena.check_map()
	local entities = entitylist() --// Map entities
	local info_ct = 0 --// CT spawn counter
	local info_t = 0 --// TT spawn counter
	local arenas = {} --// Arenas numbers
	local duplicate = 0 --// Number of duplicates found

	--// Through each map entity
	for _, e in pairs(entities) do
		local typename = entity(e.x, e.y, "typename") --// Entity typename
		local name = entity(e.x, e.y, "name") --// Entity's name
		
		--// Updates the spawn counter
		if typename == "Info_CT" then
			info_ct = info_ct + 1
		elseif typename == "Info_T" then
			info_t = info_t + 1
		end

		--// Is this entity an arena ?
		if string.match(name, "arena_(%d+)") then
			--// Arena level
			local num = tonumber(string.match(name, "arena_(%d+)")) 

			if arena.inArray(arenas, num) then --// Found the pair
				duplicate = duplicate + 1
			else --// First passage
				arenas[#arenas + 1] = num
			end
		end
	end

	--// Spawn counters don't match
	if info_ct ~= info_t then
		arena.disable("TT & CT Spawns aren't equal !")
		arena.debug("TT (" .. info_t .. ") CT (" .. info_ct .. ")")
		return
	end

	--// No arena spawns !
	if #arenas == 0 then
		arena.disable("No arenas spawns found !")
		return
	end

	--// There's a problem about spawn names
	if #arenas ~= duplicate then
		arena.disable("Some arenas don't match !")
		arena.debug("Arenas (" .. #arenas .. ") Duplicates (" .. duplicate .. ")")
		return
	end

	arena.MAX_STAGE = #arenas
	arena.debug("Map [OK]")
end

--[[---------------------------------------------
	Init spawn locations
--]]---------------------------------------------
function arena.init_spawns()
	local entities = entitylist() --// Map entities

	--// Through each map entity
	for _, e in pairs(entities) do
		local name = entity(e.x, e.y, "name") --// Entity's name
		local typename = entity(e.x, e.y, "typename") --// Entity's type name

		--// An arena entity
		if string.match(name, "arena_(%d+)") then
			--// Arena stage
			local stage = tonumber(string.match(name, "arena_(%d+)")) 
	
			--// CT or TT Spawn update (converted to pixels)
			if typename == "Info_T" then
				arena.spawn_tt[stage] = {e.x * 32 + 16, e.y * 32 + 16}
			elseif typename == "Info_CT" then
				arena.spawn_ct[stage] = {e.x * 32 + 16, e.y * 32 + 16}
			end 
		end
	end
end

--[[---------------------------------------------
	Prints arenas infos
--]]---------------------------------------------
function arena.debug_map()
	if not arena.DEBUG_MAP then 
		return 
	end

	local debug_changed = false

	if not arena.DEBUG then 
		debug_changed = true
		arena.DEBUG = true 
	end

	--// Loop through each arena
	for i = 1, arena.MAX_STAGE do
		--// Prints <stage> (TT Coordinates) (CT Coordinates)
		arena.debug("Arena <" .. i .. "> (" .. arena.spawn_tt[i][1] .. 
			"," .. arena.spawn_tt[i][2] .. ") (" .. 
			arena.spawn_ct[i][1] .. "," .. arena.spawn_ct[i][2] .. ")")
	end

	if debug_changed then
		arena.DEBUG = false
	end
end

--[[---------------------------------------------
	Loads available arena maps into memory
--]]---------------------------------------------
function arena.loadMaps()
	addhook("log", "grabmaps")

	function grabmaps(text)
		if text ~= "----- Maps -----" and text:match("^ma_") then
			arena.maps[#arena.maps + 1] = text
			arena.maps_votes[text] = {}
		end
	end

	parse("maps")
	freehook("log", "grabmaps")
	
	--// Build the map menu
	local menu = arena.create_menu("Maps")

	for i = 1, #arena.maps do
		local map = arena.maps[i] --// a map name
		
		menu.buttons[i] = {
			label = map, func = arena.add_map_vote, 
			args = i
		}
	end

	arena.menus["map"] = menu
	grabmaps = nil
end